Inline XBRL sample: Faurecia - Consolidated statement of comprehensive income

## 9.1. Consolidated statement
of comprehensive income

(in € millions) | Notes | 2014 | 2013 | 2012
--- | --- | --- | --- | ---
Sales | 4 | 18,828.9 | 18,028.6 | 17,364.5
Cost of sales | 5 | ( 17,271.8) | ( 16,636.1) | ( 16,038.7)
Research and development costs | 5 | ( 235.5) | ( 254.0) | ( 239.6)
Selling and administrative expenses | 5 | ( 648.3) | ( 600.2) | ( 569.9)
Operating income (loss) |  | 673.3 | 538.3 | 516.3
Other non-operating income | 6 | 5.1 | 4.8 | 15.5
Other non-operating expense | 6 | (91.6) | (111.6) | (102.7)
Income on loans, cash investments and marketable securities |  | 8.0 | 9.0 | 10.2
Finance costs |  | ( 191.1) | ( 196.9) | ( 175.4)
Other financial income and expense | 7 | ( 60.5) | ( 46.4) | ( 31.9)
Income (loss) before tax of fully consolidated companies |  | 343.2 | 197.2 | 232.0

These samples have been prepared by XBRL International as a technology demonstration, and the accuracy of figures and information contained within this sample should not be relied upon for any purpose whatsoever.

Figure tagged in three reports 1,234.

## Linkable section

This section can be linked to from another document.